# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 5.15.1
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore

qt_resource_data = b"\
\x00\x00\x05l\
\x00\
\x00\x17Ex\x9c\xedX\xdbn\xdb6\x18\xbe\xcfSh\
\xeaE\x1b,\xa2H\x8a\x92%\xc5v\x81\xb5(P`\
\xdb\xc5\x96a\x97\x03#\xd16QI\x14(:v\xfa\
P{\x88=\xd9~\xead+Q\x80bE\xb7v-\
\x91\xc0\xe2\x7f\xe0\x7f\xfa\xf8\xc9\xc9\xf2\xe5\xb1,\x9c;\
\xa1\x1b\xa9\xaa\x95K\x10v\x1dQe*\x97\xd5v\xe5\
\xfev\xf3\xc6\x8b]\xa71\xbc\xcay\xa1*\xb1r+\
\xe5\xbe\x5c_,\xbf\xf3<\xe7\x95\x16\xdc\x88\xdc9H\
\xb3s\xdeV\xef\x9a\x8c\xd7\xc2y\xb13\xa6N}\xff\
p8 \xd9\x0b\x91\xd2[\xff\xd2\xf1\xbc\xf5\xc5\xc5\xb2\
\xb9\xdb^8\x8e\x03q\xab&\xcd\xb3\x95\xdb;\xd4{\
]\xb4\x86y\xe6\x8bB\x94\xa22\x8dO\x10\xf1\xdd\x93\
yv2\xcflty'2U\x96\xaajZ\xcf\xaa\
yvf\xac\xf3\xcdhm\xb39\x04\xad\x11I\x92\xc4\
\xc7\xd4\xa7\xd4\x03\x0b\xaf\xb9\xaf\x0c?zSW\xc8q\
\xce\x95b\x8c}\xd0\x9d,?\xcc*m\xa0\xa15\xfc\
\x8e\xe6\x83\x005j\xaf3\xb1\x01?\x81*a\xfc\xd7\
7\xafG\xa5\x87Qn\xf2\xb3c\x86~N\xa2N\x9a\
\x5c\xf1R45\xcfD\xe3\x0f\xf2\xd6\xff s\xb3[\
\xb94,\xcbv\xbf\x13r\xbb3g\x82;)\x0e?\
\xa8\xe3\xca\xc5\x0evh\x08?\x9d\xf8\x84\x0c\xd2\x0ad\
\xber\xa1\xb6\x98-\xbam\x1f$\x1d\x0d1J(\x0a\
\x9c\x17\x94\xe10d\xd1\x95C1\x89=\x1cx\x84\x5c\
\xb6.Cui\xae2\x9b\xee\xca\xcd\x8c\xcc\xbdBm\
\x15\x1a\xba6\x1e+\x8e\xb5\xd2\xc6\xdb\xc8Bt\xb6\xfe\
N\x95\xc2\xcf\xf9\x9d\xccK_l\xf9~+\xfc\xd6\xbf\
\xd6j\xabyY\x0a\xdd\xee\xff8\xdbk\xd1u\x19z\
\x92\x01T\xfcS\xbc\xba\x9a\x8fw\xcck\x98\x15\x8b\xd1\
b1\xab\xbf?\xd3\xaf\xc1`\x99\x8bMc\x0d\xbb\x06\
\xd9]\xcc\x88\xeb\xf8\xadr\xac\xd8\x96\x90\xdbN\x9fL\
oy\xd3M\xc8qj\xbe\x054\x17J\xaf\xdcg\x9b\
v\xf5\x8a[\xa5s\xa1\x07U\xd4\xae\x89J\xc1\xc4\xa5\
\xb9\xef\xeeo\x7f\xf6\x90\xb1=u\xd4\xe3y}\xb3\xe3\
\xb9:\x00\x1a\x1e*\xdf+U\x82\x18\xc5\x0f\x15\x19 \
\xc5\xa3\x0ca\xba =\x14\xce\xb5\x10\x8aE(\x0e\x93\
\x05~\xe4\x0ac\xdf\xdb\xcb\xed\xed+i\xe0\x02\xf5\x00\
<w\xdfkm\x0d\x0a~/\xa0\xe2\xf6\x83\xf4F\xcd\
N\x1d\xb6\xdavn\xc3\x8b\xb1u\xa3\xebAVP\x89\
\xd7\xc3\x9d\xc4\xf4QI\xbd\xc5p\x01\x08f\xc1\x13&\
P\x22\xc5\x8fj\xeb\x95\xb6\xd9\xc9S\x9e%?\xcaR\
\xbe\x17\x90\xe5\xd0\xef\x8d4 \xd6[YyF\xd5\xb3\
\xf2Bl\xcc\xacBw\xa9\xcehn\x951vBx\
\x80Z)\x0c\xcf\xb9\xe1'\x80\x0d\x92\x98\xb1\x16\xaa`\
\x04\xb4\x97\xfe\xf2\xfaM\xb7\x83}\x96\xa5\xbf+\xfd\xae\
\xdf\xc2\xb2\x06\xfcV\xed!\xa8\xbb\x1e\xc5\xcb<K\x81\
\xa8Jn\xd6\xb2\x04\xd4X\x8e\xfb\x1e\x88i\xe9\x9f\x14\
\x13cs_\x8b\xd3\xa1\xdd\xb1\xc3]\x9c\xa5\xfd<+\
\xa5u\xf2\x7f5\xb2(\xde\xda }ag\x87JS\
\x88u\x1b\xb3{\x1c\xaa\xf0\xfb2\xfa\x22\xfd\xb3*\x97\
\xfe\xd0\x85v\xb7}0\xb5\x82\xdf\x8ab\xe5\xfehq\
\xe6\x90\x873\xddj\xb5\xafK\x95\x8b\x1e\x89\xee\xa9\xb7\
\x13d\x1a\xcd\xab\xc6\xb6a\xe5\xb6\x8f\x05\xbc\x1c_x\
a\x84p\xb8\xc0\x84]ya\x80b\x12\x05\xf1\xe2r\
\x18\x84\x11G3\x14\x07\x8dL[\xe6^\xb954I\
\xe8\xbb\x01\xdc\x00zs_\x80|\xa3\xe0R\xb4\xcfi\
e\xdb]\x5c\xb7\x92;\xae%\xaf\xccDvh\xe1=\
\x115F\x0b\x93\xed\xa62\x00iJ)\x0a\x17v\xc5\
Q}\xbc.d%\xfa\xdb\x91\x12D\xc3\xcep\xc3K\
Y\xdc\xa7o\xf6f\xaf\xf9\xcdO\x22\xbf\xf6\x86\x06y\
\xddI\xb5\xc8\xe4Ff\xf0NVU\xfa\xfcdx\xe5\
\xfc\xdc\x06|>I\xd6+\xe4\x96\x83\x89h\xe6J\xf1\
\xe0\xdcyE\x05\xd4\xa1e6\xe8l\x03=\x0egU\
i\x06\x8c!\xf4u!\x0c|x\xb6\x93\xf0\x15&\xc5\
P\xd1\x018r*\xd0\xd2\xc0\xb3g\x87\x9a\x16\xda3\
\xb7\xfdAU\xb6S:-e\x9e\x17\xe2\x1a\xde9E\
\xfa\x0c\xb7\xab\xddx=\x8d\xa6\xe4\x1az\xa9\xde\xd9)\
T\xa2\x7f\xee('\xc5\x88F,\x8c\x83\x80\x8e\xc3\x03\
\x1a\x89\x02\x14\xd1$`d\x14\x02},\x00\x0e\x0c\xb3\
\xc5b\x14ZH\xd9DH\x90\xc0]]\x1a\xc8\xb9:\
\xdd\x9f\xf1-\xa2\x95\x05\x83\x9d\x93{\xd2\xb6\xbe\xd6\x01\
\x9c\xe9\x99|6\xfa\x13\xf1G\xa0=U\xd2\xfa\xd5\xd2\
o\x83\xc0\xfd\xb3\x89~V0&\x11J\x02X\x94\xb1\
/\x0d\xc6]n\xa2=\xc9k\x00\xc1\x80\xce\xe6\x0b\xc3\
\xf8\x82 \x16\x86\x04'\x13\x8cS\x940\x16\x122\x87\
\xf1\xf8c0\x1eM1\xfe8\xfa\x13\xf1?9\x0a\x19\
\x22v\xe1(\x81)\xfc\x8f@\xf7a\x80z\x929n\
>g\xe6\x98\xcc\xec\x1bs\xfc\xdb\xcc\x11\xa1\x00'Q\
D?\x909\x18\xa6\xff\x9c9\x18\xc6\x0f\x98\xe3Q\xf4\
\xff\x889\x12\x14\xb7_\xc2p\xf85\x12G\x87'\x92\
D\x94o\xe6\xf14C*2\xff\x9cY\x05\x10\x14\xd1\
\x98\xc6\xd1\xb7\xef#\x9f\x98U\x18\x0eq\x1c\x07\xc9\x84\
U\x18\x8a\x22L\x22v\xce*\x11C1]\x84\xc1\x1c\
\xa9\x9c\xbeQ\x9c\xfd%\x07\xa3(\xc4\x0b\x82p@\x17\
8\x88\xaf0\xcc\x14\xb0G\xe2\xf0\xf2c8\x88=\xe0\
\xa0G\xb9\xceg\xfb\xa9!\x1b!\x16\x13FX@\xbf\
F\x0az\x0aT\xeb\xbf\xfe|L3K\x7f\xbb\xbeX\
\xda\x7f\x81\xac/\xfe\x06r\x0f\x8e]\
"

qt_resource_name = b"\
\x00\x06\
\x07\x03}\xc3\
\x00i\
\x00m\x00a\x00g\x00e\x00s\
\x00\x0d\
\x00\xc0\xb3\x07\
\x00c\
\x00t\x00i\x00d\x00-\x00l\x00o\x00g\x00o\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x12\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01t\xfe\x85\x04\x1d\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
